diff --git a/km3io/daq.py b/km3io/daq.py
index 591ab6584965035681fd141b12d79c0ef05a014b..63c245e975072daa54b4193f3c6bd82f7a727868 100644
--- a/km3io/daq.py
+++ b/km3io/daq.py
@@ -29,7 +29,13 @@ def get_rate(value):
 
 
 def unpack_bits(value):
-    """Helper to unpack bits to bool flags (little endian)"""
+    """Helper to unpack bits to bool flags (little endian)
+
+    Parameters
+    ----------
+    value : int32
+        The integer value to be parsed.
+    """
     value = np.array(value).astype(np.int32)
     value = value.reshape(-1, 1)
     value = value.view(np.uint8)